==> xwxapt-2.2.tar.bz2: xwxapt-2.2/src/shared.c <==
/*  shared.c
 *
 *  Shared global variables
 */

/*
 *  xwxapt: An application to decode APT signals from
 *  weather satellites and produce image(s) of the weather.
 *
 *  Copyright (C) 2001  Neoklis Kyriazis
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License as
 *  published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details:
 *
 *  http://www.gnu.org/copyleft/gpl.txt
 */

#include "shared.h"

/* Runtime config data */
rc_data_t rc_data;

/* Pixel buffer */
guchar *gbl_pixel_buf;

int
  gbl_sat_type, /* Weather satellite type number   */
  gbl_sync_ref, /* Required position of sync train */
  gbl_sync_err, /* Deviation from sync reference   */
  gbl_duration,	/* Processing duration */
  gbl_line_idx; /* Index to audio samples buffer   */

/* List of required sync position references */
int gbl_sync_refs[] = { SYNC_REFS };

/* Audio/DSP samples buffer */
short gbl_line_buffer[BUFFER_SIZE];

/* Pixel buffer for display */
GdkPixbuf *gbl_pixbuf;

/* Pixbuf rowstride and num of channels */
gint
  gbl_rowstride,
  gbl_n_channels;

GtkWidget
  *xwxapt_main_window, /* xwxapt's top window   */
  *gbl_text_scroller,  /* Text view scroller    */
  *gbl_level_pbar,     /* Audio level prog. bar */
  *gbl_sync_pbar,      /* Sync level prog. bar  */
  *gbl_status_table,   /* Status widgets' table */
  *gbl_sync_icon,      /* Sync status indicator */
  *gbl_apt_image;      /* Image to be displayed */

/* Text buffer for text view */
GtkTextBuffer *gbl_text_buffer;

/* Pixel buffer for display */
GdkPixbuf *gbl_pixbuf = NULL;

/* Pixbuf rowstride and num of channels */
gint
  gbl_rowstride,
  gbl_n_channels;

/* Satellite type names */
char *gbl_sat_names[] = { SAT_NAMES };

char
  gbl_samples_file[MAX_FILE_NAME+1], /* Samples file name */
  gbl_image_file  [MAX_FILE_NAME+1]; /* Image files name  */

/* Pointer to samples file */
FILE *gbl_samples_fp = NULL;

/* Buffer for reading in DSP data */
short *gbl_dsp_buffer = NULL;

/*------------------------------------------------------------------------*/

==> xwxapt-2.4.tar.bz2: xwxapt-2.4/src/shared.c <==
/*  shared.c
 *
 *  Shared global variables
 */

/*
 *  xwxapt: An application to decode APT signals from
 *  weather satellites and produce image(s) of the weather.
 *
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License as
 *  published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details:
 *
 *  http://www.gnu.org/copyleft/gpl.txt
 */

#include "shared.h"

/* Runtime config data */
rc_data_t rc_data;

/* Pixel buffer */
guchar *gbl_pixel_buf;

int
  gbl_sat_type, /* Weather satellite type number   */
  gbl_sync_ref, /* Required position of sync train */
  gbl_sync_err, /* Deviation from sync reference   */
  gbl_duration,	/* Processing duration */
  gbl_line_idx; /* Index to audio samples buffer   */

/* List of required sync position references */
int gbl_sync_refs[] = { SYNC_REFS };

/* Audio/DSP samples buffer */
short gbl_line_buffer[BUFFER_SIZE];

/* Pixbuf rowstride and num of channels */
gint
  gbl_rowstride,
  gbl_n_channels;

GtkWidget
  *xwxapt_main_window, /* xwxapt's top window   */
  *gbl_text_scroller,  /* Text view scroller    */
  *gbl_level_pbar,     /* Audio level prog. bar */
  *gbl_sync_pbar,      /* Sync level prog. bar  */
  *gbl_status_table,   /* Status widgets' table */
  *gbl_sync_icon,      /* Sync status indicator */
  *gbl_apt_image;      /* Image to be displayed */

/* Text buffer for text view */
GtkTextBuffer *gbl_text_buffer;

/* Pixel buffer for display */
GdkPixbuf *gbl_pixbuf;

/* Pixbuf rowstride and num of channels */
gint
  gbl_rowstride,
  gbl_n_channels;

/* Satellite type names */
char *gbl_sat_names[] = { SAT_NAMES };

char
  gbl_samples_file[MAX_FILE_NAME], /* Samples file name */
  gbl_image_file  [MAX_FILE_NAME]; /* Image files name  */

/* Pointer to samples file */
FILE *gbl_samples_fp = NULL;

/* Buffer for reading in DSP data */
short *gbl_dsp_buffer = NULL;

/*------------------------------------------------------------------------*/
